// Same as the original, except the JOptionFrame is disabled.

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.text.*;     // for DecimalFormat class

/** GPACalc.java.
    Computes GPA needed for Off-Campus Study.
    Allows user to: <br>
    a) Compute projected GPA, <br>
    b) Compute minimum GPA needed this semester to reach 2.7 GPA overall.
 */
public class GPACalcMod extends JApplet
                implements ActionListener, ItemListener{

    private JTextField creditsTF, creditsThisSemesterTF, 
            currentGPAtf, anticipatedGPAtf, projectedGPAtf, neededGPAtf;
            
    private JLabel GPAthisSemesterLabel, projectedGPAlabel, anticipatedGPAlabel, neededGPAlabel;
    
    private JRadioButton computeProjectedGPAradioButton, 
                         computeNeededGPAradioButton;

    private ButtonGroup group;
    
    private JButton computeButton, moreInfoButton;
    
    /** Constructs the instance variables and determines their roles in the 
        applet, sets the listeners, and creates the layout. 
     */
    public void init(){
        // Text fields. 
        creditsTF = new JTextField("");
        creditsThisSemesterTF  = new JTextField("4");
        currentGPAtf = new JTextField("");
        projectedGPAtf = new JTextField("");
        anticipatedGPAtf = new JTextField("");
        projectedGPAtf.setEditable(false);
        neededGPAtf = new JTextField("");
        neededGPAtf.setEditable(false);

        // Labels
        projectedGPAlabel = new JLabel("Projected GPA  ", 
                                    SwingConstants.RIGHT);
        anticipatedGPAlabel = new JLabel("Enter anticipated GPA this semester  ", 
                                    SwingConstants.RIGHT);
        neededGPAlabel = new JLabel("Minimum GPA needed this semester  ", SwingConstants.RIGHT);
        neededGPAlabel.setForeground(Color.lightGray);

        // Radio buttons and button group.
        computeProjectedGPAradioButton
            = new JRadioButton("Compute projected GPA", true);
        computeNeededGPAradioButton = new 
            JRadioButton("Compute needed GPA", false);
        group = new ButtonGroup();
        group.add(computeProjectedGPAradioButton);
        group.add(computeNeededGPAradioButton);

        computeButton = new JButton("Compute");
        moreInfoButton = new JButton("More Info");

        // Add listeners.
        computeButton.addActionListener(this);
        moreInfoButton.addActionListener(this);
        computeProjectedGPAradioButton.addItemListener(this);
        computeNeededGPAradioButton.addItemListener(this);

        setLayout();

    } // end of init method

    ///////////////////////////////////////////////////////////
        
    /** Opens textfields to allow data entry based on which radio 
        button has been selecteded. Triggered by the radio buttons. */
    public void itemStateChanged(ItemEvent e){
        if (e.getSource() == computeProjectedGPAradioButton){
            anticipatedGPAtf.setEditable(true);
            anticipatedGPAlabel.setForeground(Color.black);
            projectedGPAlabel.setForeground(Color.black);
            neededGPAlabel.setForeground(Color.lightGray);
            neededGPAtf.setText("");
        }
        else{ // selected computeNeedededGPAradioButton
            anticipatedGPAlabel.setForeground(Color.lightGray);
            anticipatedGPAtf.setEditable(false);
            anticipatedGPAtf.setText("");
            projectedGPAtf.setText("");
            projectedGPAlabel.setForeground(Color.lightGray);
            neededGPAlabel.setForeground(Color.black);
        }
    } // end of itemStateChanged method
    
    /////////////////////////////////////////////////////////////////

    /** Performs computation based on which radio button has been 
        selected. Triggered by compute button. */
    public void actionPerformed( ActionEvent event ){
        
        if (event.getSource() == computeButton){

            double currentGPA = Double.parseDouble(currentGPAtf.getText());
            double credits = Double.parseDouble(creditsTF.getText());
            double creditsNow = Double.parseDouble(creditsThisSemesterTF.getText());
            DecimalFormat df = new DecimalFormat("0.00");

          //  if (group.getSelection() == computeProjectedGPAradioButton){  Why doesn't this work?
            if (computeProjectedGPAradioButton.isSelected()){
                double anticipatedGPA = Double.parseDouble(anticipatedGPAtf.getText());
                double projectedGPA = (currentGPA*credits + anticipatedGPA*creditsNow)/(credits + creditsNow);
                projectedGPAtf.setText(df.format(projectedGPA));
            }
            else{  // selected radio button is computeNeededGPAradioButton
                double neededGPA = (2.7*(credits + creditsNow) - currentGPA*credits)/creditsNow;
                neededGPAtf.setText(df.format(neededGPA));
            }
        }

        if (event.getSource() == moreInfoButton){
//             String message = "Enter the number of courses you have completed "
//                 + "at Wabash. \nInclude failed courses.  Include retaken courses only once.";
//             JOptionPane.showMessageDialog(null,message);
        }

    } // end of actionPerformed method

    /////////////////////////////////////////////////////////////////

    // Sets the layout of the applet.
    private void setLayout(){
        ////////////// Create panels /////////////////////////
        // Io panel 
        JPanel ioPanel = new JPanel(new GridLayout(8,2));
        ioPanel.setBackground(Color.white);
        ioPanel.add(new JLabel("Enter current GPA  ", SwingConstants.RIGHT));
        ioPanel.add(currentGPAtf);
        ioPanel.add(new JLabel("Enter number of Wabash courses completed  ", SwingConstants.RIGHT));
            JPanel tempPanel = new JPanel(new GridLayout(1,2));
            tempPanel.add(creditsTF); tempPanel.add(moreInfoButton);
        ioPanel.add(tempPanel);
        ioPanel.add(new JLabel("Enter number of courses this semester  ", 
                                    SwingConstants.RIGHT));
        ioPanel.add(creditsThisSemesterTF);
        ioPanel.add(new JLabel("Select computation method  ", 
                                    SwingConstants.RIGHT));

        // RadioButton panel contains the two radio buttons.
        JPanel radioButtonPanel = new JPanel(new GridLayout(2,1));
        radioButtonPanel.add(computeProjectedGPAradioButton);
        radioButtonPanel.add(computeNeededGPAradioButton);
        
        ioPanel.add(radioButtonPanel);
        ioPanel.add(anticipatedGPAlabel);
        ioPanel.add((anticipatedGPAtf));
        
        ioPanel.add(new JLabel("Click compute button ==>  ", 
                                    SwingConstants.RIGHT));
        ioPanel.add(computeButton);

        ioPanel.add(projectedGPAlabel);
        ioPanel.add((projectedGPAtf));
        ioPanel.add(neededGPAlabel);
        ioPanel.add((neededGPAtf));

        /////////////////////////////////////////////////////////////

        // Finally, put it all together in the content pane.
        Container window = getContentPane();
        window.setBackground(Color.red);
        window.setLayout(new BorderLayout());       
        window.add(BorderLayout.NORTH,
            new JLabel("Wabash Off-Campus Study GPA Calculator", SwingConstants.CENTER));
        window.add(BorderLayout.CENTER, ioPanel);
        String message = "WARNING: If you are retaking a course this semester, this calculation will not be accurate!";
        window.add(BorderLayout.SOUTH, new JLabel(message, SwingConstants.CENTER));

    } // end setLayout method
    
}
